@@ -1,19 +1,29 @@
 """
 This module contains `jsonclass`, the decorator for JSON Classes.
 """
+from __future__ import annotations
 from jsonclasses.keypath import identical_key
-from typing import Optional, Union, Callable, overload, cast
+from typing import (
+    Optional, Union, Callable, TypeVar, overload, cast, TYPE_CHECKING
+)
 from dataclasses import dataclass
-from .jconf import (JConf, OnCreate, CanCreate, OnDelete, CanUpdate,
-                     CanDelete, CanRead, OnUpdate)
+from .jconf import (
+    JConf, OnCreate, CanCreate, OnDelete, CanUpdate, CanDelete, CanRead,
+    OnUpdate
+)
 from .jfield import JField
 from .cdef import Cdef
 from .jsonclassify import jsonclassify
 from .jobject import JObject
+if TYPE_CHECKING:
+    from .types import Types
+
+
+T = TypeVar('T', bound=type)
 
 
 @overload
-def jsonclass(cls: type) -> type[JObject]: ...
+def jsonclass(cls: T) -> T | type[JObject]: ...
 
 
 @overload
@@ -28,19 +38,20 @@ def jsonclass(
     validate_all_fields: Optional[bool] = None,
     abstract: Optional[bool] = None,
     reset_all_fields: Optional[bool] = None,
-    on_create: Optional[Union[OnCreate, list[OnCreate]]] = None,
-    on_update: Optional[Union[OnUpdate, list[OnUpdate]]] = None,
-    on_delete: Optional[Union[OnDelete, list[OnDelete]]] = None,
-    can_create: Optional[Union[CanCreate, list[CanCreate]]] = None,
-    can_update: Optional[Union[CanUpdate, list[CanUpdate]]] = None,
-    can_delete: Optional[Union[CanDelete, list[CanDelete]]] = None,
-    can_read: Optional[Union[CanRead, list[CanRead]]] = None,
-) -> Callable[[type], type[JObject]]: ...
+    output_null: Optional[bool] = None,
+    on_create: OnCreate | list[OnCreate] | Types | None = None,
+    on_update: OnUpdate | list[OnUpdate] | Types | None = None,
+    on_delete: OnDelete | list[OnDelete] | Types | None = None,
+    can_create: CanCreate | list[CanCreate] | Types | None = None,
+    can_update: CanUpdate | list[CanUpdate] | Types | None = None,
+    can_delete: CanDelete | list[CanDelete] | Types | None = None,
+    can_read: CanRead | list[CanRead] | Types | None = None,
+) -> Callable[[T], T | type[JObject]]: ...
 
 
 @overload
 def jsonclass(
-    cls: type,
+    cls: T,
     class_graph: Optional[str] = 'default',
     key_encoding_strategy: Optional[Callable[[str], str]] = None,
     key_decoding_strategy: Optional[Callable[[str], str]] = None,
@@ -50,18 +61,19 @@ def jsonclass(
     validate_all_fields: Optional[bool] = None,
     abstract: Optional[bool] = None,
     reset_all_fields: Optional[bool] = None,
-    on_create: Optional[Union[OnCreate, list[OnCreate]]] = None,
-    on_update: Optional[Union[OnUpdate, list[OnUpdate]]] = None,
-    on_delete: Optional[Union[OnDelete, list[OnDelete]]] = None,
-    can_create: Optional[Union[CanCreate, list[CanCreate]]] = None,
-    can_update: Optional[Union[CanUpdate, list[CanUpdate]]] = None,
-    can_delete: Optional[Union[CanDelete, list[CanDelete]]] = None,
-    can_read: Optional[Union[CanRead, list[CanRead]]] = None,
-) -> type[JObject]: ...
+    output_null: Optional[bool] = None,
+    on_create: OnCreate | list[OnCreate] | Types | None = None,
+    on_update: OnUpdate | list[OnUpdate] | Types | None = None,
+    on_delete: OnDelete | list[OnDelete] | Types | None = None,
+    can_create: CanCreate | list[CanCreate] | Types | None = None,
+    can_update: CanUpdate | list[CanUpdate] | Types | None = None,
+    can_delete: CanDelete | list[CanDelete] | Types | None = None,
+    can_read: CanRead | list[CanRead] | Types | None = None,
+) -> T | type[JObject]: ...
 
 
 def jsonclass(
-    cls: Optional[type] = None,
+    cls: Optional[T] = None,
     class_graph: Optional[str] = 'default',
     key_encoding_strategy: Optional[Callable[[str], str]] = None,
     key_decoding_strategy: Optional[Callable[[str], str]] = None,
@@ -71,14 +83,15 @@ def jsonclass(
     validate_all_fields: Optional[bool] = None,
     abstract: Optional[bool] = None,
     reset_all_fields: Optional[bool] = None,
-    on_create: Optional[Union[OnCreate, list[OnCreate]]] = None,
-    on_update: Optional[Union[OnUpdate, list[OnUpdate]]] = None,
-    on_delete: Optional[Union[OnDelete, list[OnDelete]]] = None,
-    can_create: Optional[Union[CanCreate, list[CanCreate]]] = None,
-    can_update: Optional[Union[CanUpdate, list[CanUpdate]]] = None,
-    can_delete: Optional[Union[CanDelete, list[CanDelete]]] = None,
-    can_read: Optional[Union[CanRead, list[CanRead]]] = None,
-) -> Union[Callable[[type], type[JObject]], type[JObject]]:
+    output_null: Optional[bool] = None,
+    on_create: OnCreate | list[OnCreate] | Types | None = None,
+    on_update: OnUpdate | list[OnUpdate] | Types | None = None,
+    on_delete: OnDelete | list[OnDelete] | Types | None = None,
+    can_create: CanCreate | list[CanCreate] | Types | None = None,
+    can_update: CanUpdate | list[CanUpdate] | Types | None = None,
+    can_delete: CanDelete | list[CanDelete] | Types | None = None,
+    can_read: CanRead | list[CanRead] | Types | None = None,
+) -> Union[Callable[[T], T | type[JObject]], T | type[JObject]]:
     """The jsonclass object class decorator. To declare a jsonclass class, use
     this syntax:
 
@@ -102,6 +115,7 @@ def jsonclass(
             validate_all_fields=validate_all_fields,
             abstract=abstract,
             reset_all_fields=reset_all_fields,
+            output_null=output_null,
             on_create=on_create,
             on_update=on_update,
             on_delete=on_delete,
@@ -128,6 +142,7 @@ def jsonclass(
                 validate_all_fields=validate_all_fields,
                 abstract=abstract,
                 reset_all_fields=reset_all_fields,
+                output_null=output_null,
                 on_create=on_create,
                 on_update=on_update,
                 on_delete=on_delete,
