@@ -1,25 +1,23 @@
 """This module defines the `jsonclassify` function."""
 from __future__ import annotations
-from typing import Any, Optional, Union
-from datetime import datetime
-from inspect import signature
+from typing import Any, Callable, Optional, Union
+from inspect import signature, getmro
 from .jobject import JObject
 from .ctx import Ctx, CtxCfg
 from .fdef import Fdef, FStore, FType
+from .types import Types
 from .modifiers.instanceof_modifier import InstanceOfModifier
 from .jfield import JField
 from .isjsonclass import isjsonobject
-from .mgraph import MGraph
 from .ograph import OGraph
-from .owned_dict import OwnedDict
-from .owned_list import OwnedList
-from .owned_collection_utils import (
-    to_owned_dict, to_shape_dict, to_owned_list, unowned_copy_dict,
-    unowned_copy_list
+from .odict import OwnedDict
+from .olist import OwnedList
+from .outils import (
+    to_owned_dict, to_owned_list, unowned_copy_dict, unowned_copy_list
 )
 from .keypath import (
-    concat_keypath, initial_keypath, reference_key, single_key_args,
-    compound_key_args, keypath_split
+    concat_keypath, initial_keypath, single_key_args, compound_key_args,
+    keypath_split
 )
 from .excs import (AbstractJSONClassException, ValidationException,
                          JSONClassResetError, JSONClassResetNotEnabledError,
@@ -27,6 +25,7 @@ from .excs import (AbstractJSONClassException, ValidationException,
                          UnauthorizedActionException)
 
 
+
 def __init__(self: JObject, **kwargs: dict[str, Any]) -> None:
     """Initialize a new jsonclass object from keyed arguments or a dict.
     This method is suitable for accepting web and malformed inputs. Eager
@@ -37,11 +36,15 @@ def __init__(self: JObject, **kwargs: dict[str, Any]) -> None:
         raise AbstractJSONClassException(self.__class__)
     self._set_initial_status()
     for field in self.__class__.cdef.fields:
-        setattr(self, field.name, None)
-        if field.fdef.field_storage == FStore.LOCAL_KEY:
+        if field.fdef.fstore != FStore.CALCULATED:
+            setattr(self, field.name, None)
+        if field.fdef.fstore == FStore.LOCAL_KEY:
             transformer = self.__class__.cdef.jconf.ref_key_encoding_strategy
             local_key = transformer(field)
-            setattr(self, local_key, None)
+            if field.fdef.ftype == FType.LIST:
+                setattr(self, local_key, to_owned_list(self, [], local_key))
+            else:
+                setattr(self, local_key, None)
             self._local_keys.add(local_key)
             self._local_key_map[local_key] = field.name
     self._set(single_key_args(kwargs), fill_blanks=True)
@@ -88,22 +91,14 @@ def _set_to_container(self: JObject,
                       value: Any,
                       fdef: Fdef,
                       used_items: list[str]) -> None:
-    if fdef.field_type == FType.INSTANCE:
+    if fdef.ftype == FType.INSTANCE:
         if dest is None:
             raise ValueError(f"value in {'.'.join(used_items)} is None")
         if len(items) == 1:
             dest._set({items[0]: value}, fill_blanks=False)
         else:
             dest._keypath_set({'.'.join(items): value})
-    elif fdef.field_type == FType.SHAPE:
-        if dest is None:
-            raise ValueError(f"value in {'.'.join(used_items)} is None")
-        if len(items) == 1:
-            dest[items[0]] = value
-        else:
-            fdef = fdef.shape_types[items[0]].fdef
-            self._set_to_container(dest[items[0]], items[1:], value, fdef, used_items + [items[0]])
-    elif fdef.field_type == FType.LIST:
+    elif fdef.ftype == FType.LIST:
         if dest is None:
             raise ValueError(f"value in {'.'.join(used_items)} is None")
         if len(items) == 1:
@@ -111,7 +106,7 @@ def _set_to_container(self: JObject,
         else:
             fdef = fdef.item_types.fdef
             self._set_to_container(dest[int(items[0])], items[1:], value, fdef, used_items + [items[0]])
-    elif fdef.field_type == FType.DICT:
+    elif fdef.ftype == FType.DICT:
         if dest is None:
             raise ValueError(f"value in {'.'.join(used_items)} is None")
         if len(items) == 1:
@@ -143,18 +138,29 @@ def update(self: JObject, **kwargs: dict[str, Any]) -> JObject:
     return self
 
 
-def tojson(self: JObject, ignore_writeonly: bool = False) -> dict[str, Any]:
+def tojson(self: JObject,
+           ignore_writeonly: bool = False,
+           reverse_relationship: bool = False,
+           output_null: Optional[bool] = None) -> dict[str, Any]:
     """Convert this JSON Class object to JSON dict.
 
     Args:
-        ignore_writeonly (Optional[bool]): Whether ignore writeonly marks on
+        ignore_writeonly (bool): Whether ignore writeonly marks on
         fields. Be careful when setting it to True.
 
+        reverse_relationship (bool): Whether including reverse relationship in
+        json outputs.
+
+        output_null (bool): Whether output null instead of leaving unexisting
+        fields for null values.
+
     Returns:
         dict[str, Any]: A dict represents this object's JSON object.
     """
     self._can_read_check()
-    ctxcfg = CtxCfg(ignore_writeonly=ignore_writeonly)
+    ctxcfg = CtxCfg(ignore_writeonly=ignore_writeonly,
+                    reverse_relationship=reverse_relationship,
+                    output_null=output_null)
     ctx = Ctx.rootctx(self, ctxcfg)
     return InstanceOfModifier(self.__class__).tojson(ctx)
 
@@ -267,7 +273,7 @@ def persisted_modified_fields(self: JObject) -> tuple[str]:
     retval: list[str] = []
     cdef = self.__class__.cdef
     for name in self._modified_fields:
-        if not cdef.field_named(name).fdef.is_temp_field:
+        if cdef.field_named(name).fdef.fstore != FStore.TEMP:
             retval.append(name)
     return tuple(retval)
 
@@ -347,7 +353,12 @@ def complete(self: JObject) -> JObject:
     """Fetch missing field values from the underlying ORM.
     """
     if self.is_partial:
+        saved_modified_fields = list(self._modified_fields)
+        saved_is_modified = self._is_modified
         self._orm_complete()
+        self._is_modified = saved_is_modified
+        self._modified_fields = saved_modified_fields
+    return self
 
 
 def _orm_complete(self: JObject) -> JObject:
@@ -394,6 +405,8 @@ def _set_initial_status(self: JObject) -> None:
     setattr(self, '_local_keys', set())
     setattr(self, '_local_key_map', {})
     setattr(self, '_unlinked_objects', {})
+    setattr(self, '_link_keys', {})
+    setattr(self, '_unlink_keys', {})
     setattr(self, '_graph', OGraph())
     setattr(self, '_operator', None)
 
@@ -403,6 +416,18 @@ def _mark_not_new(self: JObject) -> None:
     setattr(self, '_is_new', False)
 
 
+def _add_link_key(self: JObject, fname: str, key: str | int) -> None:
+    if self._link_keys.get(fname) is None:
+        self._link_keys[fname] = []
+    self._link_keys[fname].append(key)
+
+
+def _add_unlink_key(self: JObject, fname: str, key: str | int) -> None:
+    if self._unlink_keys.get(fname) is None:
+        self._unlink_keys[fname] = []
+    self._unlink_keys[fname].append(key)
+
+
 def _add_unlinked_object(self: JObject,
                          field_name: str,
                          obj: JObject) -> None:
@@ -440,7 +465,7 @@ def _set_on_save(self: JObject) -> None:
 
 def _clear_temp_fields(self: JObject) -> None:
     for field in self.__class__.cdef.fields:
-        if field.fdef.is_temp_field:
+        if field.fdef.fstore == FStore.TEMP:
             setattr(self, field.name, None)
 
 
@@ -456,55 +481,49 @@ def _orm_restore(self: JObject) -> None:
     pass
 
 
+def _can_cu_check_common(self: JObject,
+                         callbacks: list[Types | Callable],
+                         action: str) -> None:
+    if len(callbacks) == 0:
+        return
+    from .types import Types
+    operator = getattr(self, '_operator')
+    if operator is None:
+        raise UnauthorizedActionException('no operator')
+    for callback in callbacks:
+        if isinstance(callback, Types):
+            ctx = Ctx.rootctx(self, CtxCfg())
+            tval = callback.modifier.transform(ctx)
+            try:
+                callback.modifier.validate(ctx.nval(tval))
+            except ValidationException:
+                raise UnauthorizedActionException(f'cannot {action}')
+        else:
+            result = callback(self, operator)
+            if result is not None and result is not True:
+                if isinstance(result, str):
+                    raise UnauthorizedActionException(result)
+                else:
+                    raise UnauthorizedActionException(f'cannot {action}')
+
+
 def _can_create_or_update_check(self: JObject) -> None:
     if self.is_new:
-        for callback in self.__class__.cdef.jconf.can_create:
-            operator = getattr(self, '_operator')
-            if operator is None:
-                raise UnauthorizedActionException('no operator')
-            result = callback(self, operator)
-            if result is not None and result is not True:
-                if isinstance(result, str):
-                    raise UnauthorizedActionException(result)
-                else:
-                    raise UnauthorizedActionException('cannot create')
+        self._can_cu_check_common(
+            self.__class__.cdef.jconf.can_create, 'create')
     else:
-        for callback in self.__class__.cdef.jconf.can_update:
-            operator = getattr(self, '_operator')
-            if operator is None:
-                raise UnauthorizedActionException('no operator')
-            result = callback(self, operator)
-            if result is not None and result is not True:
-                if isinstance(result, str):
-                    raise UnauthorizedActionException(result)
-                else:
-                    raise UnauthorizedActionException('cannot update')
+        self._can_cu_check_common(
+            self.__class__.cdef.jconf.can_update, 'update')
 
 
 def _can_delete_check(self: JObject) -> None:
-    for callback in self.__class__.cdef.jconf.can_delete:
-        operator = getattr(self, '_operator')
-        if operator is None:
-            raise UnauthorizedActionException('no operator')
-        result = callback(self, operator)
-        if result is not None and result is not True:
-            if isinstance(result, str):
-                raise UnauthorizedActionException(result)
-            else:
-                raise UnauthorizedActionException('cannot delete')
+    self._can_cu_check_common(
+        self.__class__.cdef.jconf.can_delete, 'delete')
 
 
 def _can_read_check(self: JObject) -> None:
-    for callback in self.__class__.cdef.jconf.can_read:
-        operator = getattr(self, '_operator')
-        if operator is None:
-            raise UnauthorizedActionException('no operator')
-        result = callback(self, operator)
-        if result is not None and result is not True:
-            if isinstance(result, str):
-                raise UnauthorizedActionException(result)
-            else:
-                raise UnauthorizedActionException('cannot read')
+    self._can_cu_check_common(
+        self.__class__.cdef.jconf.can_read, 'read')
 
 
 def _run_on_create_callbacks(self: JObject) -> None:
@@ -554,19 +573,37 @@ def __setattr__(self: JObject, name: str, value: Any) -> None:
         return
     # use special method for local keys
     if name in self._local_keys:
-        if str(value) == str(getattr(self, name)):
+        if value == getattr(self, name):
             return
-        if value is None:
-            self.__original_setattr__(name, value)
-            setattr(self, self._local_key_map[name], None)
-        else:
-            # temporarily set to none if key is modified
-            # in the future, may query object from graph
-            self.__original_setattr__(name, value)
-            setattr(self, self._local_key_map[name], None)
+        field_name = self._local_key_map[name]
+        field = self.__class__.cdef.field_named(field_name)
+        if field.fdef.ftype == FType.INSTANCE:
+            if value is None:
+                self.__original_setattr__(name, value)
+                setattr(self, field_name, None)
+            else:
+                # temporarily set to none if key is modified
+                # in the future, may query object from graph
+                self.__original_setattr__(name, value)
+                setattr(self, field_name, None)
+        elif field.fdef.ftype == FType.LIST:
+            olist = to_owned_list(self, value or [], name)
+            self.__original_setattr__(name, olist)
+            if (value is None) or (value is []):
+                setattr(self, field_name, [])
+            else:
+                new_list = []
+                curvals = getattr(self, field_name)
+                if curvals is None:
+                    curvals = []
+                for item in value:
+                    existitem = next((v for v in curvals if v._id == item), None)
+                    if existitem is not None:
+                        new_list.append(existitem)
+                setattr(self, field_name, new_list)
         if not self.is_new:
             setattr(self, '_is_modified', True)
-            self._modified_fields.add(self._local_key_map[name])
+            self._modified_fields.add(field_name)
     # use original setattr for non JSON class fields
     try:
         field = self.__class__.cdef.field_named(name)
@@ -574,16 +611,18 @@ def __setattr__(self: JObject, name: str, value: Any) -> None:
         self.__original_setattr__(name, value)
         return
     # this is a JSON class field attribute
-    if hasattr(self, name) and value == getattr(self, name):
-        lk = field.fdef.field_storage is FStore.LOCAL_KEY
-        value_none = value is None
-        if lk and value_none:
-            if getattr(self, reference_key(field), None) is not None:
-                pass
-            else:
-                return
+    if field.fdef.fstore == FStore.CALCULATED:
+        if field.fdef.setter is None:
+            raise Exception('do not set to readonly calculation field')
         else:
+            if callable(field.fdef.setter):
+                field.fdef.setter(value, self)
+            else:
+                ctx = Ctx.rootctxp(self, name, None, value)
+                field.fdef.setter.modifier.transform(ctx)
             return
+    if hasattr(self, name) and value == getattr(self, name):
+        return
     # track modified and previous value
     if not self.is_new:
         setattr(self, '_is_modified', True)
@@ -596,26 +635,53 @@ def __setattr__(self: JObject, name: str, value: Any) -> None:
     if isinstance(value, list):
         value = to_owned_list(self, value, name)
     if isinstance(value, dict):
-        if field.fdef.field_type == FType.SHAPE:
-            value = to_shape_dict(self, value, name)
-        else:
-            value = to_owned_dict(self, value, name)
+        value = to_owned_dict(self, value, name)
     if field.fdef.is_ref:
         if hasattr(self, name):
             self.__unlink_field__(field, getattr(self, name))
         self.__original_setattr__(name, value)
-        if field.fdef.field_storage == FStore.LOCAL_KEY:
-            if value is None:
-                transformer = self.__class__.cdef.jconf.ref_key_encoding_strategy
-                self.__original_setattr__(transformer(field), None)
-            if isjsonobject(value):
-                transformer = self.__class__.cdef.jconf.ref_key_encoding_strategy
-                self.__original_setattr__(transformer(field), value._id)
+        if field.fdef.fstore == FStore.LOCAL_KEY:
+            rkes = self.__class__.cdef.jconf.ref_key_encoding_strategy
+            rname = rkes(field)
+            if field.fdef.ftype == FType.INSTANCE:
+                if value is None:
+                    self.__original_setattr__(rname, None)
+                if isjsonobject(value):
+                    self.__original_setattr__(rname, value._id)
+            elif field.fdef.ftype == FType.LIST:
+                if value is None:
+                    olist = to_owned_list(self, [], rname)
+                    self.__original_setattr__(rname, olist)
+                else:
+                    keys = []
+                    for item in value:
+                        if item is not None:
+                            keys.append(item._id)
+                    olist = to_owned_list(self, keys, rname)
+                    self.__original_setattr__(rname, olist)
         self.__link_field__(field, value)
     else:
         self.__original_setattr__(name, value)
 
 
+def __getattribute__(self: JObject, name: str, default: Any = None) -> Any:
+    """This getattr takes calculated fields into account.
+    """
+    if name.startswith('_'):
+        cls = getmro(type(self))[-2]
+        return super(cls, self).__getattribute__(name)
+    cdef = self.__class__.cdef
+    if name in cdef.calc_field_names:
+        getter = cdef.field_named(name).fdef.getter
+        if callable(getter):
+            return getter(self)
+        else:
+            ctx = Ctx.rootctx(self, CtxCfg(), self)
+            return getter.modifier.transform(ctx)
+    cls = getmro(type(self))[-2]
+    return super(cls, self).__getattribute__(name)
+
+
 def __odict_will_change__(self: JObject, odict: OwnedDict) -> None:
     # record previous value
     name = initial_keypath(odict.keypath)
@@ -625,10 +691,10 @@ def __odict_will_change__(self: JObject, odict: OwnedDict) -> None:
         if field.fdef.has_linked:
             return
         if name not in self.previous_values:
-            if field.fdef.field_type == FType.DICT:
+            if field.fdef.ftype == FType.DICT:
                 self.previous_values[name] = unowned_copy_dict(
                     getattr(self, name))
-            if field.fdef.field_type == FType.LIST:
+            if field.fdef.ftype == FType.LIST:
                 self.previous_values[name] = unowned_copy_list(
                     getattr(self, name))
 
@@ -656,28 +722,47 @@ def __odict_del__(self, odict: OwnedDict, val: Any) -> None:
 def __olist_will_change__(self, olist: OwnedList) -> None:
     # record previous value
     name = initial_keypath(olist.keypath)
-    field = self.__class__.cdef.field_named(name)
+    try:
+        field = self.__class__.cdef.field_named(name)
+    except:
+        field = None
+    if not field:
+        return
     if self.__class__.cdef.jconf.reset_all_fields or \
             field.fdef.has_reset_modifier:
         if field.fdef.has_linked:
             return
         if name not in self.previous_values:
-            if field.fdef.field_type == FType.DICT:
+            if field.fdef.ftype == FType.DICT:
                 self.previous_values[name] = unowned_copy_dict(
                     getattr(self, name))
-            if field.fdef.field_type == FType.LIST:
+            if field.fdef.ftype == FType.LIST:
                 self.previous_values[name] = unowned_copy_list(
                     getattr(self, name))
 
 
 def __olist_add__(self: JObject, olist: OwnedList, idx: int, val: Any) -> None:
     cdef = self.__class__.cdef
+    if olist.keypath in self._local_keys:
+        fname = self._local_key_map[olist.keypath]
+        if not self._is_new and fname not in self._modified_fields:
+            self._modified_fields.add(fname)
+            self._is_modified = True
+        return
     try:
         field = cdef.field_named(olist.keypath)
     except ValueError:
         field = None
     if field is not None and field.fdef.is_ref:
         self.__link_field__(field, [val])
+        if field.fdef.fstore == FStore.LOCAL_KEY:
+            rkes = cdef.jconf.ref_key_encoding_strategy
+            rk = rkes(field)
+            rlist = getattr(self, rk)
+            if len(rlist) != len(olist):
+                if val._id is None:
+                    raise ValueError('a referenced object must have a valid primary key')
+                rlist.insert(idx, val._id)
     if isinstance(val, dict):
         olist[idx] = to_owned_dict(self, val,
                                    concat_keypath(olist.keypath, idx))
@@ -692,12 +777,34 @@ def __olist_add__(self: JObject, olist: OwnedList, idx: int, val: Any) -> None:
 
 def __olist_del__(self: JObject, olist: OwnedList, val: Any) -> None:
     cdef = self.__class__.cdef
+    if olist.keypath in self._local_keys:
+        fname = self._local_key_map[olist.keypath]
+        if not self._is_new and fname not in self._modified_fields:
+            self._modified_fields.add(fname)
+            self._is_modified = True
+        flist = getattr(self, fname)
+        if isinstance(flist, list):
+            if len(flist) != len(olist):
+                # TODO: reorder flist here
+                # TODO: replace the underneath implementation
+                match = next((v for v in flist if v._id == val), "PLACEHOLDER")
+                if match != "PLACEHOLDER":
+                    flist.remove(match)
+        return
     try:
         field = cdef.field_named(olist.keypath)
     except ValueError:
         field = None
     if field and field.fdef.is_ref:
         self.__unlink_field__(field, [val])
+        if field.fdef.fstore == FStore.LOCAL_KEY:
+            ## TODO: replace the underneath implementation
+            rkes = cdef.jconf.ref_key_encoding_strategy
+            rk = rkes(field)
+            rlist = getattr(self, rk)
+            if len(rlist) != len(olist):
+                if val is not None and val._id in rlist:
+                    rlist.remove(val._id)
     # record modified
     if not self.is_new:
         setattr(self, '_is_modified', True)
@@ -705,6 +812,7 @@ def __olist_del__(self: JObject, olist: OwnedList, val: Any) -> None:
 
 
 def __olist_sor__(self, olist: OwnedList) -> None:
+    # TODO: sort local keys here
     # record modified
     if not self.is_new:
         setattr(self, '_is_modified', True)
@@ -713,11 +821,11 @@ def __olist_sor__(self, olist: OwnedList) -> None:
 
 def __unlink_field__(self: JObject, field: JField, value: Any) -> None:
     items: list[JObject] = []
-    if field.fdef.field_type == FType.INSTANCE:
+    if field.fdef.ftype == FType.INSTANCE:
         if not isjsonobject(value):
             return
         items = [value]
-    if field.fdef.field_type == FType.LIST:
+    if field.fdef.ftype == FType.LIST:
         if not isinstance(value, list):
             return
         items = list(value)
@@ -726,16 +834,16 @@ def __unlink_field__(self: JObject, field: JField, value: Any) -> None:
         other_field = field.foreign_field
         if other_field is None:
             return
-        if other_field.fdef.field_type == FType.INSTANCE:
+        if other_field.fdef.ftype == FType.INSTANCE:
             if getattr(item, other_field.name) is self:
                 item.__original_setattr__(other_field.name, None)
                 of = other_field
-                if of.fdef.field_storage == FStore.LOCAL_KEY:
+                if of.fdef.fstore == FStore.LOCAL_KEY:
                     tsfm = item.__class__.cdef.jconf.ref_key_encoding_strategy
                     item.__original_setattr__(tsfm(other_field), None)
                     item._modified_fields.add(other_field.name)
                 item._add_unlinked_object(other_field.name, self)
-        elif other_field.fdef.field_type == FType.LIST:
+        elif other_field.fdef.ftype == FType.LIST:
             other_list = getattr(item, other_field.name)
             if isinstance(other_list, list):
                 if self in other_list:
@@ -745,11 +853,11 @@ def __unlink_field__(self: JObject, field: JField, value: Any) -> None:
 
 def __link_field__(self: JObject, field: JField, value: Any) -> None:
     items: list[JObject] = []
-    if field.fdef.field_type == FType.INSTANCE:
+    if field.fdef.ftype == FType.INSTANCE:
         if not isjsonobject(value):
             return
         items = [value]
-    if field.fdef.field_type == FType.LIST:
+    if field.fdef.ftype == FType.LIST:
         if not isinstance(value, list):
             return
         items = value
@@ -758,11 +866,11 @@ def __link_field__(self: JObject, field: JField, value: Any) -> None:
         other_field = field.foreign_field
         if other_field is None:
             return
-        if other_field.fdef.field_type == FType.INSTANCE:
+        if other_field.fdef.ftype == FType.INSTANCE:
             if getattr(item, other_field.name) != self:
                 setattr(item, other_field.name, self)
                 item._del_unlinked_object(other_field.name, self)
-        elif other_field.fdef.field_type == FType.LIST:
+        elif other_field.fdef.ftype == FType.LIST:
             if not isinstance(getattr(item, other_field.name), list):
                 setattr(item, other_field.name, [self])
                 item._del_unlinked_object(other_field.name, self)
@@ -781,7 +889,7 @@ def __link_graph__(self: JObject, other: JObject) -> None:
             self._graph.put(self)
     except UnlinkableJSONClassException:
         pass
-    self._graph.merged_graph(other._graph)
+    self._graph = self._graph.merged_graph(other._graph)
 
 
 def jsonclassify(class_: type) -> type[JObject]:
@@ -801,9 +909,6 @@ def jsonclassify(class_: type) -> type[JObject]:
     # public methods
     class_.__init__ = __init__
     class_.set = jsonobject_set
-    class_._set = _set
-    class_._keypath_set = _keypath_set
-    class_._set_to_container = _set_to_container
     class_.update = update
     class_.tojson = tojson
     class_.validate = validate
@@ -811,6 +916,7 @@ def jsonclassify(class_: type) -> type[JObject]:
     class_.opby = opby
     class_.is_new = is_new
     class_.is_modified = is_modified
+    class_.is_partial = is_partial
     class_.is_deleted = is_deleted
     class_.modified_fields = modified_fields
     class_.persisted_modified_fields = persisted_modified_fields
@@ -822,12 +928,17 @@ def jsonclassify(class_: type) -> type[JObject]:
     class_.restore = restore
     class_.complete = complete
     # protected methods
+    class_._set = _set
+    class_._keypath_set = _keypath_set
+    class_._set_to_container = _set_to_container
     class_._orm_complete = _orm_complete
     class_._data_dict = _data_dict
     class_._mark_new = _mark_new
     class_._mark_unmodified = _mark_unmodified
     class_._set_initial_status = _set_initial_status
     class_._mark_not_new = _mark_not_new
+    class_._add_link_key = _add_link_key
+    class_._add_unlink_key = _add_unlink_key
     class_._add_unlinked_object = _add_unlinked_object
     class_._del_unlinked_object = _del_unlinked_object
     class_._clear_unlinked_object = _clear_unlinked_object
@@ -836,6 +947,7 @@ def jsonclassify(class_: type) -> type[JObject]:
     class_._database_write = _database_write
     class_._orm_delete = _orm_delete
     class_._orm_restore = _orm_restore
+    class_._can_cu_check_common = _can_cu_check_common
     class_._can_create_or_update_check = _can_create_or_update_check
     class_._can_delete_check = _can_delete_check
     class_._can_read_check = _can_read_check
@@ -846,6 +958,7 @@ def jsonclassify(class_: type) -> type[JObject]:
     # private methods
     class_.__original_setattr__ = class_.__setattr__
     class_.__setattr__ = __setattr__
+    class_.__getattribute__ = __getattribute__
     class_.__odict_will_change__ = __odict_will_change__
     class_.__odict_add__ = __odict_add__
     class_.__odict_del__ = __odict_del__
