@@ -8,4 +8,4 @@ class AnyModifier(Modifier):
     """Field marked with any modifier can be any value."""
 
     def define(self, fdef: Fdef) -> None:
-        fdef._field_type = FType.ANY
+        fdef._ftype = FType.ANY
