@@ -3,7 +3,6 @@ from __future__ import annotations
 from typing import Any, TYPE_CHECKING
 from datetime import date, datetime
 from ..fdef import FType
-from ..excs import ValidationException
 from .type_modifier import TypeModifier
 if TYPE_CHECKING:
     from ..ctx import Ctx
@@ -15,7 +14,7 @@ class DatetimeModifier(TypeModifier):
     def __init__(self):
         super().__init__()
         self.cls = datetime
-        self.field_type = FType.DATETIME
+        self.ftype = FType.DATETIME
 
     def transform(self, ctx: Ctx) -> Any:
         if ctx.val is None:
