@@ -1,15 +1,16 @@
 """module for default modifier."""
 from __future__ import annotations
-from typing import Any, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING, Callable
 from .modifier import Modifier
 if TYPE_CHECKING:
     from ..ctx import Ctx
+    from ..types import Types
 
 
 class DefaultModifier(Modifier):
     """Default modifier assigns field a default value if value is `None`."""
 
-    def __init__(self, default: Any) -> None:
+    def __init__(self, default: Any | Callable | Types) -> None:
         self.default = default
 
     def transform(self, ctx: Ctx) -> Any:
@@ -18,4 +19,4 @@ class DefaultModifier(Modifier):
         if callable(self.default):
             return self.default()
         else:
-            return self.default
+            return self.resolve_param(self.default, ctx)
