@@ -7,4 +7,4 @@ class EmbeddedModifier(Modifier):
     """This modifier marks value as embedded on the hosting object."""
 
     def define(self, fdef: Fdef) -> None:
-        fdef._field_storage = FStore.EMBEDDED
+        fdef._fstore = FStore.EMBEDDED
