@@ -1,5 +1,5 @@
 """module for linkedby modifier."""
-from ..fdef import DeleteRule, Fdef, FStore
+from ..fdef import DeleteRule, Fdef, FStore, FType, Nullability
 from .modifier import Modifier
 
 
@@ -10,8 +10,11 @@ class LinkedByModifier(Modifier):
         self.foreign_key = foreign_key
 
     def define(self, fdef: Fdef) -> None:
-        fdef._field_storage = FStore.FOREIGN_KEY
+        fdef._fstore = FStore.FOREIGN_KEY
         fdef._foreign_key = self.foreign_key
         fdef._use_join_table = False
         if fdef._delete_rule is None:
             fdef._delete_rule = DeleteRule.NULLIFY
+        if fdef._ftype == FType.LIST:
+            if fdef._collection_nullability is Nullability.UNDEFINED:
+                fdef._collection_nullability = Nullability.NONNULL
