@@ -12,7 +12,7 @@ class LinkedInModifier(Modifier):
         self.cls = cls
 
     def define(self, fdef: Fdef) -> None:
-        fdef._field_storage = FStore.FOREIGN_KEY
+        fdef._fstore = FStore.FOREIGN_KEY
         fdef._join_table_cls = self.cls
         fdef._use_join_table = True
         if fdef._delete_rule is None:
