@@ -4,7 +4,7 @@ from ..fdef import Fdef, Strictness
 
 
 class StrictModifier(Modifier):
-    """A strict modifier marks shape to disallow undefined keys."""
+    """A strict modifier marks object to disallow undefined keys."""
 
     def define(self, fdef: Fdef) -> None:
         fdef._strictness = Strictness.STRICT
