@@ -1,7 +1,7 @@
 from __future__ import annotations
 from typing import Optional, Tuple
 from jsonclasses import jsonclass, types
-from jsonclasses.contexts import ValidatingContext
+from jsonclasses.ctx import Ctx
 
 val = 0
 oldval = 0
@@ -31,12 +31,12 @@ def callbackb(old: int, new: int) -> None:
     return new == old + 1
 
 
-def callbacks(old: int, new: int, context: ValidatingContext) -> None:
+def callbacks(old: int, new: int, context: VCtx) -> None:
     global val, oldval, newval
     val = val + 1
     oldval = old
     newval = new
-    if context.value == new + old:
+    if context.val == new + old:
         return None
     else:
         return 'invalid'
