@@ -6,11 +6,11 @@ from jsonclasses import jsonclass, types
 class Group:
     id: int = types.int.primary
     name: str
-    template: Template = types.instanceof('Template').linkedby('group').present
+    template: Template = types.objof('Template').linkedby('group').present
 
 
 @jsonclass(class_graph='grouptemplate')
 class Template:
     id: int = types.int.primary
     name: str
-    group: Group = types.linkto.instanceof('Group').required
+    group: Group = types.linkto.objof('Group').required
