@@ -17,4 +17,12 @@ class GSProductUser:
 @jsonclass(can_delete=check_user, can_read=check_user)
 class GSProduct:
     name: str
-    user: GSProductUser = types.instanceof('GSProductUser').linkto.required
+    user: GSProductUser = types.objof('GSProductUser').linkto.required
+
+
+can_types = types.getop.fval('name').eq('n')
+
+
+@jsonclass(can_delete=can_types, can_read=can_types)
+class GSTProduct:
+    name: str
