@@ -1,6 +1,6 @@
 from __future__ import annotations
-from typing import TYPE_CHECKING
-from jsonclasses import jsonclass, Link, linkedthru, types
+from typing import Annotated, TYPE_CHECKING
+from jsonclasses import jsonclass, linkedthru, types
 if TYPE_CHECKING:
     from tests.classes.linked_default_post import LinkedDefaultPost
 
@@ -8,4 +8,4 @@ if TYPE_CHECKING:
 @jsonclass
 class LinkedDefaultUser:
     name: str = types.str.default('Default User')
-    posts: Link[list[LinkedDefaultPost], linkedthru('users')]
+    posts: Annotated[list[LinkedDefaultPost], linkedthru('users')]
