@@ -2,19 +2,6 @@ from __future__ import annotations
 from jsonclasses import jsonclass, types
 
 
-@jsonclass
-class OpUser:
-    name: str = types.str.required
-    owned_teams: list[OpTeam] = types.nonnull.listof('OpTeam') \
-                                     .linkedby('owner')
-
-
-@jsonclass
-class OpTeam:
-    name: str = types.str.op(lambda o, t: o == t.owner).required
-    owner: OpUser = types.instanceof('OpUser').linkto.required
-
-
 @jsonclass
 class AsopUser:
     name: str = types.str.required
@@ -25,7 +12,7 @@ class AsopUser:
 @jsonclass
 class AsopTeam:
     name: str = types.str.required
-    owner: AsopUser = types.instanceof('AsopUser').linkto.asop(lambda o: o)
+    owner: AsopUser = types.objof('AsopUser').linkto.asop(lambda o: o)
 
 
 @jsonclass
@@ -38,4 +25,4 @@ class AsopdUser:
 @jsonclass
 class AsopdTeam:
     name: str = types.str.required
-    owner: AsopdUser = types.instanceof('AsopdUser').linkto.asopd
+    owner: AsopdUser = types.objof('AsopdUser').linkto.asopd
