@@ -7,3 +7,9 @@ from jsonclasses import jsonclass, types
 class SimpleBook:
     name: Optional[str]
     published: bool = types.bool.default(False)
+
+
+@jsonclass(output_null=True)
+class SimpleBookN:
+    name: Optional[str]
+    published: bool = types.bool.default(False)
