@@ -22,6 +22,12 @@ class CValidPassword:
     password: str = types.str.validate(lambda p, c: c.val == p).required
 
 
+@jsonclass
+class TValidPassword:
+    name: Optional[str]
+    password: int = types.int.validate(types.add(5).eq(50)).required
+
+
 @jsonclass
 class OptionalPassword:
     name: Optional[str]
