@@ -10,8 +10,7 @@ from tests.classes.linked_user import LinkedUser
 from tests.classes.linked_product import LinkedProduct
 from tests.classes.linked_customer import LinkedCustomer
 from tests.classes.linked_profile import LinkedProfile
-from tests.classes.auto_setting import AutoSetting
-from tests.classes.auto_str_setting import AutoStrSetting
+from tests.classes.new_union import NewUnion, NewRUnion, NewOUnion
 
 
 class TestAutoTypes(TestCase):
@@ -374,8 +373,8 @@ class TestAutoTypes(TestCase):
             val: 'Union[dict[str, int], int]'
         cfield = TestUnionDictType.cdef.field_named('val')
         utypes = cfield.fdef.raw_union_types
-        self.assertEqual(utypes[0].fdef.field_type, FType.DICT)
-        self.assertEqual(utypes[1].fdef.field_type, FType.INT)
+        self.assertEqual(utypes[0].fdef.ftype, FType.DICT)
+        self.assertEqual(utypes[1].fdef.ftype, FType.INT)
 
     def test_auto_generates_optional_union_with_dict_with_str_type(self):
         @jsonclass(class_graph='test_marker_auto_gen')
@@ -384,50 +383,36 @@ class TestAutoTypes(TestCase):
         object = TestOptionalUnionDictType()
         object.validate()
 
-    def test_auto_generates_nonnull_shape_with_typed_dict(self):
-        setting = AutoSetting()
-        self.assertRaisesRegex(
-            ValidationException,
-            "'preference\\.ios': value required",
-            setting.validate)
-
-    def test_auto_generates_nonnull_shape_with_typed_dict_str_form(self):
-        setting = AutoStrSetting()
-        self.assertRaisesRegex(
-            ValidationException,
-            "'preference\\.ios': value required",
-            setting.validate)
-
     def test_auto_generates_1_to_1_links(self):
         profile_field = LinkedUser.cdef.field_named('profile')
-        self.assertEqual(profile_field.fdef.field_type,
+        self.assertEqual(profile_field.fdef.ftype,
                          FType.INSTANCE)
-        self.assertEqual(profile_field.fdef.field_storage,
+        self.assertEqual(profile_field.fdef.fstore,
                          FStore.FOREIGN_KEY)
         self.assertEqual(profile_field.fdef.foreign_key, 'user')
         self.assertEqual(profile_field.fdef.use_join_table, False)
 
         user_field = LinkedProfile.cdef.field_named('user')
-        self.assertEqual(user_field.fdef.field_type,
+        self.assertEqual(user_field.fdef.ftype,
                          FType.INSTANCE)
-        self.assertEqual(user_field.fdef.field_storage,
+        self.assertEqual(user_field.fdef.fstore,
                          FStore.LOCAL_KEY)
         self.assertEqual(user_field.fdef.foreign_key, None)
         self.assertEqual(user_field.fdef.use_join_table, None)
 
     def test_auto_generates_1_to_many_links(self):
         articles_field = LinkedAuthor.cdef.field_named('articles')
-        self.assertEqual(articles_field.fdef.field_type,
+        self.assertEqual(articles_field.fdef.ftype,
                          FType.LIST)
-        self.assertEqual(articles_field.fdef.field_storage,
+        self.assertEqual(articles_field.fdef.fstore,
                          FStore.FOREIGN_KEY)
         self.assertEqual(articles_field.fdef.foreign_key, 'author')
         self.assertEqual(articles_field.fdef.use_join_table, False)
 
         author_field = LinkedArticle.cdef.field_named('author')
-        self.assertEqual(author_field.fdef.field_type,
+        self.assertEqual(author_field.fdef.ftype,
                          FType.INSTANCE)
-        self.assertEqual(author_field.fdef.field_storage,
+        self.assertEqual(author_field.fdef.fstore,
                          FStore.LOCAL_KEY)
         self.assertEqual(author_field.fdef.foreign_key, None)
         self.assertEqual(author_field.fdef.use_join_table, None)
@@ -444,3 +429,55 @@ class TestAutoTypes(TestCase):
         self.assertEqual(product1.customers, [customer1, customer2])
         self.assertEqual(customer2.products, [product1])
         self.assertEqual(product2.customers, [customer1])
+
+    def test_auto_generates_optional_with_new_union_none_syntax_str(self):
+        obj = NewUnion()
+        obj.validate()
+        obj.name = '123'
+        obj.validate()
+        obj.name = 123
+        self.assertRaises(ValidationException, obj.validate)
+
+    def test_auto_generates_optional_union_with_new_union_syntax_str(self):
+        obj = NewUnion()
+        obj.validate()
+        obj.code = '123'
+        obj.validate()
+        obj.code = 123
+        obj.validate()
+        obj.code = 123.5
+        self.assertRaises(ValidationException, obj.validate)
+
+    def test_auto_generates_required_union_with_new_union_syntax_str(self):
+        obj = NewRUnion(items=['12'])
+        self.assertRaises(ValidationException, obj.validate)
+        obj.code = '123'
+        obj.validate()
+        obj.code = 123
+        obj.validate()
+        obj.code = 123.5
+        self.assertRaises(ValidationException, obj.validate)
+
+    def test_auto_generates_required_complicated_union_with_new_union_syntax_str(self):
+        obj = NewRUnion(items=['12'], code='12')
+        obj.validate()
+        obj.items = {'a': 1, 'b': '2'}
+        obj.validate()
+        obj.items = [1]
+        self.assertRaises(ValidationException, obj.validate)
+        obj.items = {'a': 5.0}
+        self.assertRaises(ValidationException, obj.validate)
+        obj.items = None
+        self.assertRaises(ValidationException, obj.validate)
+
+    def test_auto_generates_optional_complicated_union_with_new_union_syntax_str(self):
+        obj = NewOUnion(items=['12'])
+        obj.validate()
+        obj.items = {'a': 1, 'b': '2'}
+        obj.validate()
+        obj.items = [1]
+        self.assertRaises(ValidationException, obj.validate)
+        obj.items = {'a': 5.0}
+        self.assertRaises(ValidationException, obj.validate)
+        obj.items = None
+        obj.validate()
