@@ -31,11 +31,10 @@ class TestDate(TestCase):
         with self.assertRaises(ValidationException) as context:
             deadline.validate()
         self.assertEqual(len(context.exception.keypath_messages), 1)
-        self.assertEqual(context.exception.keypath_messages['ended_at'],
+        self.assertEqual(context.exception.keypath_messages['endedAt'],
                          "value is not date")
 
     def test_date_is_datetime_str_when_tojson(self):
         deadline = SimpleDeadline(ended_at='2020-11-20T03:03:03.333Z')
         self.assertEqual(deadline.tojson(),
-                         {'endedAt': '2020-11-20T00:00:00.000Z',
-                          'message': None})
+                         {'endedAt': '2020-11-20T00:00:00.000Z'})
