@@ -1,7 +1,6 @@
 from __future__ import annotations
-from jsonclasses.fdef import FType
-from unittest import TestCase
 from datetime import date
+from unittest import TestCase
 from jsonclasses.excs import ValidationException
 from tests.classes.simple_article import SimpleArticle
 from tests.classes.simple_order import SimpleOrder
@@ -10,9 +9,8 @@ from tests.classes.simple_student import SimpleStudent
 from tests.classes.simple_deadline import SimpleDeadline
 from tests.classes.author import Author
 from tests.classes.article import Article
-from tests.classes.default_shape import DefaultShape
-from tests.classes.nest_shape_user import NestShapeUser
 from tests.classes.default_dict import DefaultDict
+from tests.classes.linked_song import LinkedSong, LinkedSinger
 
 
 class TestInitialize(TestCase):
@@ -65,11 +63,6 @@ class TestInitialize(TestCase):
                           author=author)
         self.assertEqual(author, article.author)
 
-    def test_initialize_accepts_nested_keypaths_for_nonnull_shape(self):
-        shape = DefaultShape(**{'settings.ios': False, 'settings.name': 'equal'})
-        self.assertEqual(shape.settings.ios, False)
-        self.assertEqual(shape.settings.name, 'equal')
-
     def test_initialize_accepts_nested_keypaths_for_instances(self):
         author = Author(name='Kieng')
         article = Article(**{'title': 'E Sai',
@@ -83,14 +76,75 @@ class TestInitialize(TestCase):
         author = Author(**{'name': 'Kieng', 'articles': [article], 'articles.0.title': 'QQQQQ'})
         self.assertEqual(author.articles[0].title, 'QQQQQ')
 
-    def test_initialize_accepts_nested_keypaths_for_shape_in_shape(self):
-        user = NestShapeUser(**{'name': 'N', 'grouped': {
-            'ios': {'on': True, 'off': False},
-            'android': {'on': False, 'off': True}
-        }, 'grouped.ios.on': False, 'grouped.ios.off': True})
-        self.assertEqual(user.grouped.ios['on'], False)
-        self.assertEqual(user.grouped.ios['off'], True) # TODO: use dot notation
-
     def test_initialize_accepts_nested_keypaths_for_value_in_dicts(self):
         dct = DefaultDict(**{'value.b': '3', 'value.c': '4'})
         self.assertEqual(dct.value, {'a': '1', 'b': '3', 'c': '4'})
+
+    def test_initialized_object_list_local_keys_can_be_accessed(self):
+        song = LinkedSong()
+        self.assertEqual(song.singers, [])
+        self.assertEqual(song.singer_ids, [])
+
+    def test_initialized_object_list_add_local_object_syncs_local_key(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        song.singers = [singer1]
+        self.assertEqual(song.singer_ids, [1])
+        song.singers.append(singer2)
+        self.assertEqual(song.singer_ids, [1, 2])
+
+    def test_initialized_object_list_del_local_object_syncs_local_key(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        song.singers = [singer1]
+        self.assertEqual(song.singer_ids, [1])
+        song.singers.append(singer2)
+        self.assertEqual(song.singer_ids, [1, 2])
+        song.singers.remove(singer2)
+        self.assertEqual(song.singer_ids, [1])
+
+    def test_initialized_object_list_assign_local_object_syncs_local_key(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        singer3 = LinkedSinger(id=3)
+        singer4 = LinkedSinger(id=4)
+        song.singers = [singer1]
+        self.assertEqual(song.singer_ids, [1])
+        song.singers.append(singer2)
+        self.assertEqual(song.singer_ids, [1, 2])
+        song.singers = [singer3, singer4]
+        self.assertEqual(song.singer_ids, [3, 4])
+        self.assertEqual(song.singers, [singer3, singer4])
+
+    def test_initialized_object_list_add_local_key_syncs_local_object(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        song.singers = [singer1, singer2]
+        song.singer_ids.append(3)
+        self.assertEqual(song.singers, [singer1, singer2])
+
+    def test_initialized_object_list_del_local_key_syncs_local_object(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        song.singers = [singer1, singer2]
+        self.assertEqual(singer2.songs, [song])
+        song.singer_ids.remove(2)
+        self.assertEqual(song.singers, [singer1])
+        self.assertEqual(singer2.songs, [])
+
+    def test_initialized_object_list_assign_local_key_syncs_local_object(self):
+        song = LinkedSong(id=1)
+        singer1 = LinkedSinger(id=1)
+        singer2 = LinkedSinger(id=2)
+        singer3 = LinkedSinger(id=3)
+        singer4 = LinkedSinger(id=4)
+        song.singers = [singer1]
+        self.assertEqual(song.singer_ids, [1])
+        song.singer_ids = [7, 8, 1, 9, 10]
+        self.assertEqual(song.singers, [singer1])
+        self.assertEqual(song.singer_ids, [7, 8, 1, 9, 10])
