@@ -3,6 +3,9 @@ from unittest import TestCase
 from typing import List, Dict, Optional
 from jsonclasses import jsonclass, types
 from jsonclasses.excs import ValidationException
+from tests.classes.simple_book import SimpleBook, SimpleBookN
+from tests.classes.linked_profile import LinkedProfileN, LinkedProfile
+from tests.classes.simple_language import SimpleLanguage
 
 
 @jsonclass(class_graph='test_instanceof_22')
@@ -17,7 +20,7 @@ class User:
 class Post:
     id: int = types.int.primary
     name: str
-    user: User = types.linkto.instanceof('User').required
+    user: User = types.linkto.objof('User').required
     comments: List[Comment] = types.listof('Comment').linkedby('post').required
 
 
@@ -25,10 +28,10 @@ class Post:
 class Comment:
     id: int = types.int.primary
     content: str
-    post: Post = types.linkto.instanceof('Post').required
-    parent: Optional[Comment] = types.linkto.instanceof('Comment')
+    post: Post = types.linkto.objof('Post').required
+    parent: Optional[Comment] = types.linkto.objof('Comment')
     children: List[Comment] = types.listof('Comment').linkedby('parent').required
-    commenter: User = types.linkto.instanceof('User').required
+    commenter: User = types.linkto.objof('User').required
 
 
 input = {
@@ -106,7 +109,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_1')
         class User:
             name: str = types.str
-            address: Address = types.instanceof(Address)
+            address: Address = types.objof(Address)
         user = User(**{'name': 'John', 'address': {'line1': 'London', 'line2': 'Road'}})
         self.assertIsInstance(user.address, Address)
 
@@ -119,7 +122,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_1_0')
         class User:
             name: str = types.str.required
-            address: Address = types.instanceof(Address).required
+            address: Address = types.objof(Address).required
         user = User(**{'name': 'John', 'address': {}})
         self.assertEqual(user.address.line1, 'Line1')
         self.assertEqual(user.address.line2, 'Line2')
@@ -138,7 +141,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_1_2')
         class User:
             name: str = types.str.required
-            address: Address = types.instanceof(Address).required
+            address: Address = types.objof(Address).required
         user = User(name='John')
         user.address = NewAddress(line3='1', line4='2')
         self.assertRaisesRegex(
@@ -155,7 +158,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_2')
         class User:
             name: str = types.str
-            address: Address = types.instanceof(Address)
+            address: Address = types.objof(Address)
         user = User(**{'name': 'John', 'address': {'line2': 'Road'}})
         self.assertRaisesRegex(ValidationException,
             "'address\\.line1': value required",
@@ -170,7 +173,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_3')
         class User:
             name: str = types.str
-            address: Address = types.instanceof(Address)
+            address: Address = types.objof(Address)
         user = User(**{'name': 'John', 'address': {'line2': 'Road', 'line1': 'OK'}})
         result = user.tojson()
         self.assertEqual(result, {'name': 'John', 'address': {'line1': 'OK', 'line2': 'Road'}})
@@ -184,7 +187,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_4')
         class User:
             name: str = types.str
-            addresses: List[Address] = types.listof(types.instanceof(Address))
+            addresses: List[Address] = types.listof(types.objof(Address))
         user = User(**{'name': 'John', 'addresses': [
             {'line1': 'London', 'line2': 'Road'},
             {'line1': 'Paris', 'line2': 'Road'},
@@ -204,7 +207,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_5')
         class User:
             name: str = types.str
-            addresses: List[Address] = types.listof(types.instanceof(Address))
+            addresses: List[Address] = types.listof(types.objof(Address))
         user = User(**{'name': 'John', 'addresses': [
             {'line1': 'London'},
             {'line1': 'Paris'},
@@ -220,7 +223,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_6')
         class User:
             name: str = types.str
-            addresses: List[Address] = types.listof(types.instanceof(Address))
+            addresses: List[Address] = types.listof(types.objof(Address))
         user = User(**{'name': 'John', 'addresses': [
             {'line1': 'London', 'line2': 'Road'},
             {'line1': 'Paris', 'line2': 'Road'},
@@ -234,12 +237,12 @@ class TestInstanceOfModifier(TestCase):
         class Post:
             title: str = types.str
             content: str = types.str
-            author: User = types.instanceof('User')
+            author: User = types.objof('User')
 
         @jsonclass(class_graph='test_instanceof_7')
         class User:
             name: str = types.str
-            posts: List[Post] = types.listof(types.instanceof('Post'))
+            posts: List[Post] = types.listof(types.objof('Post'))
         user = User(**{'name': 'John', 'posts': [
             {'title': 'P1', 'content': 'C1'},
             {'title': 'P2', 'content': 'C2'},
@@ -250,8 +253,8 @@ class TestInstanceOfModifier(TestCase):
         desired = {
             'name': 'John',
             'posts': [
-                {'title': 'P1', 'content': 'C1', 'author': None},
-                {'title': 'P2', 'content': 'C2', 'author': None}
+                {'title': 'P1', 'content': 'C1'},
+                {'title': 'P2', 'content': 'C2'}
             ]
         }
         self.assertEqual(result, desired)
@@ -312,12 +315,12 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof__1')
         class Staff:
             position: str
-            user: User = types.linkto.instanceof('User').required
+            user: User = types.linkto.objof('User').required
 
         @jsonclass(class_graph='test_instanceof__1')
         class User:
             name: str
-            staff: Staff = types.instanceof('Staff').linkedby('user').required
+            staff: Staff = types.objof('Staff').linkedby('user').required
 
         staff = Staff(position='CFO')
         user = User(name='John', staff=staff)
@@ -327,12 +330,12 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_13')
         class Staff:
             position: str
-            user: User = types.instanceof('User').required
+            user: User = types.objof('User').required
 
         @jsonclass(class_graph='test_instanceof_13')
         class User:
             name: str
-            staff: Staff = types.instanceof('Staff').strict.required
+            staff: Staff = types.objof('Staff').strict.required
         with self.assertRaisesRegex(ValidationException, "key is not allowed"):
             User(**{'name': 'John', 'staff': {'position': 'CEO', 'boom': True}})
 
@@ -340,12 +343,12 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_14', strict_input=True)
         class Staff:
             position: str
-            user: User = types.instanceof('User').required
+            user: User = types.objof('User').required
 
         @jsonclass(class_graph='test_instanceof_14')
         class User:
             name: str
-            staff: Staff = types.instanceof('Staff').required
+            staff: Staff = types.objof('Staff').required
         with self.assertRaisesRegex(ValidationException, "'staff\\.boom': key is not allowed"):
             User(**{'name': 'John', 'staff': {'position': 'CEO', 'boom': True}})
 
@@ -355,13 +358,13 @@ class TestInstanceOfModifier(TestCase):
         class Staff:
             id: int = types.int.primary
             position: str
-            user: User = types.linkto.instanceof('User').required
+            user: User = types.linkto.objof('User').required
 
         @jsonclass(class_graph='test_instanceof_15')
         class User:
             id: int = types.int.primary
             name: str
-            staff: Staff = types.instanceof('Staff').linkedby('user').required
+            staff: Staff = types.objof('Staff').linkedby('user').required
 
         user = User(**{'id': 1, 'name': 'John', 'staff': {'id': 1, 'position': 'CEO'}})
         self.assertEqual(user.staff.user, user)
@@ -371,12 +374,12 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_16')
         class Staff:
             position: str
-            user: User = types.instanceof('User').linkedby('staff').required
+            user: User = types.objof('User').linkedby('staff').required
 
         @jsonclass(class_graph='test_instanceof_16')
         class User:
             name: str
-            staff: Staff = types.linkto.instanceof('Staff').required
+            staff: Staff = types.linkto.objof('Staff').required
 
         user = User(**{'name': 'John', 'staff': {'position': 'CEO'}})
         self.assertEqual(user.staff.user, user)
@@ -386,7 +389,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_17')
         class Post:
             title: str
-            user: User = types.linkto.instanceof('User').required
+            user: User = types.linkto.objof('User').required
 
         @jsonclass(class_graph='test_instanceof_17')
         class User:
@@ -402,7 +405,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_18')
         class Post:
             title: str
-            user: User = types.instanceof('User').linkedby('posts').required
+            user: User = types.objof('User').linkedby('posts').required
 
         @jsonclass(class_graph='test_instanceof_18')
         class User:
@@ -418,7 +421,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_19')
         class Post:
             title: str
-            user: User = types.linkto.instanceof('User').required
+            user: User = types.linkto.objof('User').required
 
         @jsonclass(class_graph='test_instanceof_19')
         class User:
@@ -432,7 +435,7 @@ class TestInstanceOfModifier(TestCase):
         @jsonclass(class_graph='test_instanceof_20')
         class Post:
             title: str
-            user: User = types.instanceof('User').linkedby('posts').required
+            user: User = types.objof('User').linkedby('posts').required
 
         @jsonclass(class_graph='test_instanceof_20')
         class User:
@@ -498,55 +501,163 @@ class TestInstanceOfModifier(TestCase):
 
     def test_instanceof_circular_refs_tojson_do_not_infinite_loop(self):
         root_user = User(**input)
-        json = root_user.tojson()
-        result = {'comments': [{'children': None,
-                                'commenter': {'id': 1, 'name': 'U1'},
-                                'content': 'C2',
-                                'id': 2,
-                                'parent': {'content': 'C1', 'id': 1},
-                                'post': {'comments': [{'content': 'C1', 'id': 1},
-                                                      {'content': 'C2', 'id': 2},
-                                                      {'content': 'C3', 'id': 3}],
-                                         'id': 1,
-                                         'name': 'P1',
-                                         'user': {'id': 1, 'name': 'U1'}}}],
-                  'id': 1,
-                  'name': 'U1',
-                  'posts': [{'comments': [{'children': [{'content': 'C2',
-                                                         'id': 2}],
-                                           'commenter': {'id': 2, 'name': 'U2'},
-                                           'content': 'C1',
-                                           'id': 1,
-                                           'parent': None,
-                                           'post': {'id': 1, 'name': 'P1'}},
-                                          {'children': None,
-                                           'commenter': {'id': 1, 'name': 'U1'},
-                                           'content': 'C2',
-                                           'id': 2,
-                                           'parent': {'content': 'C1', 'id': 1},
-                                           'post': {'id': 1, 'name': 'P1'}},
-                                          {'children': None,
-                                           'commenter': {'id': 2, 'name': 'U2'},
-                                           'content': 'C3',
-                                           'id': 3,
-                                           'parent': None,
-                                           'post': {'id': 1, 'name': 'P1'}}],
-                             'id': 1,
-                             'name': 'P1',
-                             'user': {'id': 1, 'name': 'U1'}},
-                            {'comments': [{'children': None,
-                                           'commenter': {'id': 2, 'name': 'U2'},
-                                           'content': 'C4',
-                                           'id': 4,
-                                           'parent': None,
-                                           'post': {'id': 2, 'name': 'P2'}},
-                                          {'children': None,
-                                           'commenter': {'id': 3, 'name': 'U3'},
-                                           'content': 'C5',
-                                           'id': 5,
-                                           'parent': None,
-                                           'post': {'id': 2, 'name': 'P2'}}],
-                             'id': 2,
-                             'name': 'P2',
-                             'user': {'id': 1, 'name': 'U1'}}]}
+        json = root_user.tojson(reverse_relationship=False)
+        result = {'comments': [{
+               'commenterId': 1,
+               'content': 'C2',
+               'id': 2,
+               'parent': {'commenterId': 2,
+                          'content': 'C1',
+                          'id': 1,
+                          'postId': 1},
+               'parentId': 1,
+               'postId': 1}],
+            'id': 1,
+            'name': 'U1',
+            'posts': [{'comments': [{'children': [{'commenterId': 1,
+                                        'content': 'C2',
+                                        'id': 2,
+                                        'parentId': 1,
+                                        'postId': 1}],
+                          'commenterId': 2,
+                          'content': 'C1',
+                          'id': 1,
+                          'postId': 1},
+                         {
+                          'commenterId': 1,
+                          'content': 'C2',
+                          'id': 2,
+                          'parent': {'commenterId': 2,
+                                     'content': 'C1',
+                                     'id': 1,
+                                     'postId': 1},
+                          'parentId': 1,
+                          'postId': 1},
+                         {
+                          'commenterId': 2,
+                          'content': 'C3',
+                          'id': 3,
+                          'postId': 1}],
+            'id': 1,
+            'name': 'P1',
+            'userId': 1},
+           {'comments': [{
+                          'commenterId': 2,
+                          'content': 'C4',
+                          'id': 4,
+                          'postId': 2},
+                         {
+                          'commenterId': 3,
+                          'content': 'C5',
+                          'id': 5,
+                          'postId': 2}],
+            'id': 2,
+            'name': 'P2',
+            'userId': 1}]}
         self.assertEqual(json, result)
+
+    def test_instanceof_circular_refs_tojson_with_rr_do_not_infinite_loop(self):
+        root_user = User(**input)
+        json = root_user.tojson(reverse_relationship=True)
+        result = {'comments': [{
+               'commenter': {'id': 1, 'name': 'U1'},
+               'commenterId': 1,
+               'content': 'C2',
+               'id': 2,
+               'parent': {'commenterId': 2,
+                          'content': 'C1',
+                          'id': 1,
+                          'postId': 1},
+               'parentId': 1,
+               'post': {'comments': [{'commenterId': 2,
+                                      'content': 'C1',
+                                      'id': 1,
+                                      'postId': 1},
+                                     {'commenterId': 1,
+                                      'content': 'C2',
+                                      'id': 2,
+                                      'parentId': 1,
+                                      'postId': 1},
+                                     {'commenterId': 2,
+                                      'content': 'C3',
+                                      'id': 3,
+                                      'postId': 1}],
+                        'id': 1,
+                        'name': 'P1',
+                        'user': {'id': 1, 'name': 'U1'},
+                        'userId': 1},
+               'postId': 1}],
+            'id': 1,
+            'name': 'U1',
+            'posts': [{'comments': [{'children': [{'commenterId': 1,
+                                        'content': 'C2',
+                                        'id': 2,
+                                        'parentId': 1,
+                                        'postId': 1}],
+                          'commenter': {'id': 2, 'name': 'U2'},
+                          'commenterId': 2,
+                          'content': 'C1',
+                          'id': 1,
+                          'post': {'id': 1, 'name': 'P1', 'userId': 1},
+                          'postId': 1},
+                         {
+                          'commenter': {'id': 1, 'name': 'U1'},
+                          'commenterId': 1,
+                          'content': 'C2',
+                          'id': 2,
+                          'parent': {'commenterId': 2,
+                                     'content': 'C1',
+                                     'id': 1,
+                                     'postId': 1},
+                          'parentId': 1,
+                          'post': {'id': 1, 'name': 'P1', 'userId': 1},
+                          'postId': 1},
+                         {
+                          'commenter': {'id': 2, 'name': 'U2'},
+                          'commenterId': 2,
+                          'content': 'C3',
+                          'id': 3,
+                          'post': {'id': 1, 'name': 'P1', 'userId': 1},
+                          'postId': 1}],
+            'id': 1,
+            'name': 'P1',
+            'user': {'id': 1, 'name': 'U1'},
+            'userId': 1},
+           {'comments': [{
+                          'commenter': {'id': 2, 'name': 'U2'},
+                          'commenterId': 2,
+                          'content': 'C4',
+                          'id': 4,
+                          'post': {'id': 2, 'name': 'P2', 'userId': 1},
+                          'postId': 2},
+                         {
+                          'commenter': {'id': 3, 'name': 'U3'},
+                          'commenterId': 3,
+                          'content': 'C5',
+                          'id': 5,
+                          'post': {'id': 2, 'name': 'P2', 'userId': 1},
+                          'postId': 2}],
+            'id': 2,
+            'name': 'P2',
+            'user': {'id': 1, 'name': 'U1'},
+            'userId': 1}]}
+        self.assertEqual(json, result)
+
+    def test_instanceof_returns_empty_for_null_value_by_default(self):
+        self.assertEqual(SimpleBook().tojson(), {'published': False})
+
+    def test_instanceof_returns_null_for_null_when_option_is_set(self):
+        self.assertEqual(SimpleBookN().tojson(), {'published': False, 'name': None})
+
+    def test_instanceof_returns_empty_for_null_local_key_by_default(self):
+        self.assertEqual(LinkedProfile().tojson(), {})
+
+    def test_instanceof_returns_null_for_null_local_key_when_option_is_set(self):
+        self.assertEqual(LinkedProfileN().tojson(), {'name': None, 'userId': None, 'user': None})
+
+    def test_partial_returns_empty_for_ignored_fields_even_output_null(self):
+        l = SimpleLanguage()
+        l._is_partial = True
+        l._partial_picks = ['name']
+        l.name = 'A'
+        self.assertEqual(l.tojson(), {'name': 'A'})
