@@ -1,3 +1,4 @@
+from __future__ import annotations
 from unittest import TestCase
 from tests.classes.simple_deadline import SimpleDeadline
 from tests.classes.simple_account import SimpleAccount
@@ -11,7 +12,7 @@ class TestToJson(TestCase):
         deadline = SimpleDeadline(ended_at='2021-03-04')
         self.assertEqual(
             deadline.tojson(),
-            {'endedAt': '2021-03-04T00:00:00.000Z', 'message': None})
+            {'endedAt': '2021-03-04T00:00:00.000Z'})
 
     def test_tojson_remove_writeonly_keys_by_default(self):
         account = SimpleAccount(username='inmylife', password='iloveyoumore')
@@ -28,6 +29,14 @@ class TestToJson(TestCase):
         user = LinkedUser(name='Kia Tsiu Tai')
         user.profile = profile
         self.assertEqual(user.tojson(),
+                         {'name': 'Kia Tsiu Tai',
+                          'profile': {'name': 'Tsit Po Po'}})
+
+    def test_tojson_linked_objects_with_tojsonrr_do_not_go_to_infinite_loop(self):
+        profile = LinkedProfile(name='Tsit Po Po')
+        user = LinkedUser(name='Kia Tsiu Tai')
+        user.profile = profile
+        self.assertEqual(user.tojson(reverse_relationship=True),
                          {'name': 'Kia Tsiu Tai',
                           'profile': {'name': 'Tsit Po Po',
                                       'user': {'name': 'Kia Tsiu Tai'}}})
